"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CategoryAPI = exports.CategoryLookupType = void 0;
const ApiCallOptions_1 = require("../../Auth/ApiCallOptions");
const BaseAPI_1 = require("../BaseAPI");
const CategoryResolver_1 = require("../Resolver/CategoryResolver");
const Category_1 = require("./Category");
var CategoryLookupType;
(function (CategoryLookupType) {
    CategoryLookupType["Id"] = "id";
    CategoryLookupType["Name"] = "name";
    CategoryLookupType["Slug"] = "slug";
})(CategoryLookupType = exports.CategoryLookupType || (exports.CategoryLookupType = {}));
class CategoryAPI extends BaseAPI_1.default {
    /*async getCategoryById(categoryId: CategoryIdResolvable): Promise<Category | null> {
        const categories = await this._getCategories(CategoryLookupType.Id, [extractCategoryId(categoryId)]);
        return categories.length ? categories[0] : null;
    }

    async getCategoryByName(categoryName: CategoryNameResolvable): Promise<Category | null> {
        const categories = await this._getCategories(CategoryLookupType.Name, [extractCategoryName(categoryName)]);
        return categories.length ? categories[0] : null;
    }*/
    async getCategoryBySlug(categorySlug) {
        const categories = await this._getCategories(CategoryLookupType.Slug, [CategoryResolver_1.extractCategorySlug(categorySlug)]);
        return categories.length ? categories[0] : null;
    }
    /*getCategoriesByIds(categoryIds: CategoryIdResolvable[]): Promise<Category[]> {
        return this._getCategories(CategoryLookupType.Id, categoryIds.map(extractCategoryId), true);
    }

    getCategoriesByNames(categoryNames: CategoryNameResolvable[]): Promise<Category[]> {
        return this._getCategories(CategoryLookupType.Name, categoryNames.map(extractCategoryName), true);
    }*/
    getCategoriesBySlugs(categorySlugs) {
        return this._getCategories(CategoryLookupType.Slug, categorySlugs.map(CategoryResolver_1.extractCategorySlug), true);
    }
    async _getCategories(lookupType, param, multi = false) {
        if (param.length === 0) {
            return [];
        }
        const searchQuery = multi ? "categories" : `category(${lookupType}: "${param}")`;
        const result = await this._client.callApi({
            method: "POST",
            type: ApiCallOptions_1.ApiCallType.Base,
            url: 'categories',
            body: `
            query {
               ${searchQuery} {
                id
                name
                slug
                tags {
                  id
                  name
                }
              }
            }`
        });
        if (result.data.categories && multi) {
            let allCategories = result.data.categories.map(categoryData => new Category_1.Category(categoryData, this._client));
            let categories = [];
            param.forEach(value => {
                categories = new Array(...categories, ...(allCategories.filter(category => category[lookupType] === value)));
            });
            return categories;
        }
        else if (result.data.category) {
            return [new Category_1.Category(result.data.category, this._client)];
        }
        else {
            return [];
        }
    }
}
exports.CategoryAPI = CategoryAPI;
