"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChannelAPI = exports.ChannelLookupType = void 0;
const ApiCallOptions_1 = require("../../Auth/ApiCallOptions");
const BaseAPI_1 = require("../BaseAPI");
const ChannelResolver_1 = require("../Resolver/ChannelResolver");
const Channel_1 = require("./Channel");
const StreamAPI_1 = require("./StreamAPI");
var ChannelLookupType;
(function (ChannelLookupType) {
    ChannelLookupType["Id"] = "id";
    ChannelLookupType["Username"] = "username";
})(ChannelLookupType = exports.ChannelLookupType || (exports.ChannelLookupType = {}));
class ChannelAPI extends BaseAPI_1.default {
    get streams() {
        return new StreamAPI_1.StreamAPI(this._client);
    }
    async getChannelById(channelId) {
        const channels = await this._getCategories(ChannelLookupType.Id, [ChannelResolver_1.extractChannelId(channelId)]);
        return channels.length ? channels[0] : null;
    }
    async getChannelByName(channelName) {
        const channels = await this._getCategories(ChannelLookupType.Username, [ChannelResolver_1.extractChannelName(channelName)]);
        return channels.length ? channels[0] : null;
    }
    getChannelsByIds(channelIds) {
        return this._getCategories(ChannelLookupType.Id, channelIds.map(ChannelResolver_1.extractChannelId), true);
    }
    getChannelsByNames(channelNames) {
        return this._getCategories(ChannelLookupType.Username, channelNames.map(ChannelResolver_1.extractChannelName), true);
    }
    async _getCategories(lookupType, param, multi = false) {
        if (param.length === 0) {
            return [];
        }
        const searchQuery = multi ? "channels" : `channel(${lookupType}: "${param}")`;
        const result = await this._client.callApi({
            method: "POST",
            type: ApiCallOptions_1.ApiCallType.Base,
            url: 'channels',
            body: `
            query {
              ${searchQuery} {
                category {
                  id
                  name
                  slug
                  tags {
                    id
                    name
                  }
                }
                chatRulesHtml
                chatRulesMd
                id
                inaccessible
                language
                status
                stream {
                  avgChatters
                  avgViewers
                  countChatters
                  countViewers
                  endedAt
                  id
                  newSubscribers
                  peakChatters
                  peakViewers
                  resubSubscribers
                  startedAt
                  title
                }
                streamer {
                  avatar
                  confirmedAt
                  displayname
                  id
                  profileContentHtml
                  profileContentMd
                  username
                  youtubeIntroUrl
                }
                thumbnail
                title
              }
            }`
        });
        if (result.data.channels && multi) {
            let allChannels = result.data.channels.map(channelData => new Channel_1.Channel(channelData, this._client));
            let channels = [];
            param.forEach(value => {
                channels = new Array(...channels, ...(allChannels.filter(channel => channel[lookupType] === value)));
            });
            return channels;
        }
        else if (result.data.channel) {
            return [new Channel_1.Channel(result.data.channel, this._client)];
        }
        else {
            return [];
        }
    }
}
exports.ChannelAPI = ChannelAPI;
