"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserAPI = exports.UserLookupType = void 0;
const ApiCallOptions_1 = require("../../Auth/ApiCallOptions");
const BaseAPI_1 = require("../BaseAPI");
const UserResolver_1 = require("../Resolver/UserResolver");
const User_1 = require("./User");
var UserLookupType;
(function (UserLookupType) {
    UserLookupType["Id"] = "id";
    UserLookupType["Username"] = "username";
})(UserLookupType = exports.UserLookupType || (exports.UserLookupType = {}));
class UserAPI extends BaseAPI_1.default {
    async getUserById(userId) {
        const users = await this._getUsers(UserLookupType.Id, [UserResolver_1.extractUserId(userId)]);
        return users.length ? users[0] : null;
    }
    async getUserByName(userName) {
        const users = await this._getUsers(UserLookupType.Username, [UserResolver_1.extractUserName(userName)]);
        return users.length ? users[0] : null;
    }
    getUsersByIds(userIds) {
        return this._getUsers(UserLookupType.Id, userIds.map(UserResolver_1.extractUserId), true);
    }
    getUsersByNames(userNames) {
        return this._getUsers(UserLookupType.Username, userNames.map(UserResolver_1.extractUserName), true);
    }
    async _getUsers(lookupType, param, multi = false) {
        if (param.length === 0) {
            return [];
        }
        const searchQuery = multi ? "users" : `user(${lookupType}: "${param}")`;
        const result = await this._client.callApi({
            method: "POST",
            type: ApiCallOptions_1.ApiCallType.Base,
            url: 'users',
            body: `
            query {
               ${searchQuery} {
                avatar,
                confirmedAt,
                displayname,
                id,
                profileContentHtml,
                profileContentMd,
                username,
                youtubeIntroUrl
              }
            }`
        });
        if (result.data.users && multi) {
            let allUsers = result.data.users.map(userData => new User_1.User(userData, this._client));
            let users = [];
            param.forEach(value => {
                users = new Array(...users, ...(allUsers.filter(user => user[lookupType] === value)));
            });
            return users;
        }
        else if (result.data.user) {
            return [new User_1.User(result.data.user, this._client)];
        }
        else {
            return [];
        }
    }
}
exports.UserAPI = UserAPI;
