"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callApi = exports.callApiRaw = void 0;
const querystring_1 = require("querystring");
const ApiCallOptions_1 = require("../Auth/ApiCallOptions");
const helpers_1 = require("../Auth/helpers");
const cross_fetch_1 = require("cross-fetch");
/**
 * Makes a call to the Glimesh API using the given credentials, returning the raw Response object.
 *
 * @param options
 * @param clientId
 * @param accessToken
 * @param fetchOptions
 */
async function callApiRaw(options, clientId, accessToken, fetchOptions = {}) {
    var _a;
    const type = options.type === undefined ? ApiCallOptions_1.ApiCallType.Base : options.type;
    const url = helpers_1.getApiUrl(options.url, type);
    const params = querystring_1.stringify(options.query);
    const headers = new cross_fetch_1.Headers();
    headers.append('Accept', 'application/json');
    //headers.append('Content-Type', 'application/json');
    if (accessToken) {
        headers.append('Authorization', `Bearer ${accessToken}`);
    }
    else if (clientId && type !== ApiCallOptions_1.ApiCallType.Auth) {
        headers.append('Authorization', `Client-ID ${clientId}`);
    }
    const requestOptions = Object.assign(Object.assign({}, fetchOptions), { method: (_a = options.method) !== null && _a !== void 0 ? _a : 'GET', headers, body: options.body });
    return cross_fetch_1.default(params ? `${url}?${params}` : url, requestOptions);
}
exports.callApiRaw = callApiRaw;
/**
 * Makes a call to the Glimesh API using given credentials.
 *
 * @param options The configuration of the call.
 * @param clientId The client ID of your application.
 * @param accessToken The access token to call the API with.
 * @param fetchOptions Additional options to be passed to the `fetch` function.
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
async function callApi(options, clientId, accessToken, fetchOptions = {}) {
    const response = await callApiRaw(options, clientId, accessToken, fetchOptions);
    return helpers_1.transformApiResponse(response);
}
exports.callApi = callApi;
