import { AuthProvider, TokenInfo } from "./Auth";
import { ApiCallFetchOptions, ApiCallOptions } from "./Auth/ApiCallOptions";
import { UserAPI } from "./API/User/UserAPI";
import { CategoryAPI } from "./API/Category/CategoryAPI";
import { ChannelAPI } from "./API/Channel/ChannelAPI";
import { MyselfAPI } from "./API/User/MyselfAPI";
/**
 * Configuration for an {@ApiClient} instance.
 */
export interface ApiConfig {
    /**
     * An authentication provider that supplies tokens to the client.
     *
     * For more information, see the {@AuthProvider} documentation.
     */
    authProvider: AuthProvider;
    /**
     * Additional options to pass to the fetch method.
     */
    fetchOptions?: ApiCallFetchOptions;
}
export declare class ApiClient {
    private readonly _config;
    /**
         * Creates a new API client instance.
         *
         * @param config Configuration for the client instance.
         */
    constructor(config: ApiConfig);
    /**
     * Requests scopes from the auth provider.
     *
     * @param scopes The scopes to request.
     */
    requestScopes(scopes: string[]): Promise<void>;
    /**
     * Retrieves information about your access token.
     */
    getTokenInfo(): Promise<TokenInfo>;
    /**
     * Makes a call to the Glimesh API using your access token.
     *
     * @param options The configuration of the call.
     */
    callApi<T = any>(options: ApiCallOptions): Promise<T>;
    /** @private */
    get _authProvider(): AuthProvider;
    private _callApiInternal;
    get categories(): CategoryAPI;
    get channels(): ChannelAPI;
    get myself(): MyselfAPI;
    get users(): UserAPI;
}
