"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccessToken = void 0;
/**
 * Represents the data of an OAuth access token returned by Glimesh.
 */
class AccessToken {
    /** @private */
    constructor(data, obtainmentDate) {
        this._data = data;
        this._obtainmentDate = obtainmentDate !== null && obtainmentDate !== void 0 ? obtainmentDate : new Date();
    }
    /**
     * The access token which is necessary for every request to the Glimesh API.
     */
    get accessToken() {
        return this._data.access_token;
    }
    /**
     * The refresh token which is necessary to refresh the access token once it expires.
     */
    get refreshToken() {
        return this._data.refresh_token;
    }
    /**
     * The time when the access token will expire.
     *
     * May be `null`, in which case the token does not expire.
     * This can only be the case with very old Client IDs.
     */
    get expiryDate() {
        if (!this._data.expires_in) {
            return null;
        }
        return new Date(this._obtainmentDate.getTime() + this._data.expires_in * 1000);
    }
    get isExpired() {
        if (!this._data.expires_in) {
            return false;
        }
        return Date.now() > this._obtainmentDate.getTime() + this._data.expires_in * 1000;
    }
    /**
     * The scope the access token is valid for, i.e. what the token enables you to do.
     */
    get scope() {
        var _a;
        return (_a = this._data.scope) !== null && _a !== void 0 ? _a : [];
    }
}
exports.AccessToken = AccessToken;
