"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokenInfo = void 0;
/**
 * Information about an access token.
 */
class TokenInfo {
    /** @private */
    constructor(data) {
        this._data = data;
        this._obtainmentDate = new Date();
    }
    /**
     * The client ID.
     */
    get clientId() {
        return this._data.client_id;
    }
    /**
     * The ID of the authenticated user.
     */
    get userId() {
        return this._data.user_id;
    }
    /**
     * The name of the authenticated user.
     */
    get userName() {
        return this._data.login;
    }
    /**
     * The scopes for which the token is valid.
     */
    get scopes() {
        return this._data.scopes;
    }
    /**
     * The time when the token will expire.
     *
     * If this returns null, it means that the token never expires (happens with some old client IDs).
     */
    get expiryDate() {
        if (!this._data.expires_in) {
            return null;
        }
        return new Date(this._obtainmentDate.getTime() + this._data.expires_in * 1000);
    }
}
exports.TokenInfo = TokenInfo;
